diff --git a/tpromptuser.sh b/tpromptuser.sh
index 6d4ab8c..73effc4 100755
--- a/tpromptuser.sh
+++ b/tpromptuser.sh
@@ -3,7 +3,7 @@
 # Copyright (c) 2010-2012, TundraWare Inc, Des Plaines, IL USA
 # All Rights Reserved.
 # For Updates: http://www.tundraware.com/Software/tpromptuser
-# $Id: tpromptuser.sh,v 1.110 2012/06/05 19:31:50 tundra Exp $
+# $Id: tpromptuser.sh,v 1.111 2012/06/05 20:01:17 tundra Exp $
 
 #####
 # You are hereby granted a non-exclusive license to do whatever you
@@ -53,10 +53,10 @@
 # ---------- Nothing Should Change Below This Line ---------- #
 
 #####
 # PromptUser() - Shell Function To Prompt And Validate User Input
 #####
 
-PromptUser()
+tPromptUser()
 
 {
 
@@ -115,14 +115,7 @@
   
 }
   
-# End Of 'PromptUser()'
-
-
-
-# ---------- End Of Code ---------- #
-
-
-
+# End Of 'tPromptUser()'
 
 #####
 # Example
@@ -53,10 +53,10 @@
 
 #####
-# PromptUser() - Shell Function To Prompt And Validate User Input
+# tPromptUser() - Shell Function To Prompt And Validate User Input
 #####
 